Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nodejs/node.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBen Noordhuis <info@bnoordhuis.nl>2015-01-08 16:00:43 +0300
committerBen Noordhuis <info@bnoordhuis.nl>2015-01-09 01:21:20 +0300
commitf17f473af5e28f4ec00a518f97a84b69c426309e (patch)
tree796640291d71a73ef03ee50e023fc4798f6a6947 /tools/install.py
parent3e7a25dd95194269fd112aa5677fc5e6d4156135 (diff)
build: rename binary from node to iojs
* rename the build targets * update the test runner to use `out/{Debug,Release}/iojs` * update the installer to install the iojs binary * update one test that explicitly checks for the binary name PR-URL: https://github.com/iojs/io.js/pull/262 Reviewed-By: Bert Belder <bertbelder@gmail.com>
Diffstat (limited to 'tools/install.py')
-rwxr-xr-xtools/install.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/tools/install.py b/tools/install.py
index 77e6d0cbd10..affce2265ce 100755
--- a/tools/install.py
+++ b/tools/install.py
@@ -108,12 +108,12 @@ def npm_files(action):
if os.environ.get('PORTABLE'):
# This crazy hack is necessary to make the shebang execute the copy
# of node relative to the same directory as the npm script. The precompiled
# binary tarballs use a prefix of "/" which gets translated to "/bin/node"
# in the regular shebang modifying logic, which is incorrect since the
# precompiled bundle should be able to be extracted anywhere and "just work"
- shebang = '/bin/sh\n// 2>/dev/null; exec "`dirname "$0"`/node" "$0" "$@"'
+ shebang = '/bin/sh\n// 2>/dev/null; exec "`dirname "$0"`/iojs" "$0" "$@"'
else:
- shebang = os.path.join(node_prefix or '/', 'bin/node')
+ shebang = os.path.join(node_prefix or '/', 'bin/iojs')
update_shebang(link_path, shebang)
else:
assert(0) # unhandled action type
@@ -128,7 +128,7 @@ def subdir_files(path, dest, action):
def files(action):
exeext = '.exe' if sys.platform == 'win32' else ''
- action(['out/Release/node' + exeext], 'bin/node' + exeext)
+ action(['out/Release/iojs' + exeext], 'bin/iojs' + exeext)
if 'true' == variables.get('node_use_dtrace'):
action(['out/Release/node.d'], 'lib/dtrace/node.d')
@@ -108,12 +108,12 @@ def npm_files(action):
# This crazy hack is necessary to make the shebang execute the copy
# of node relative to the same directory as the npm script. The precompiled
- # binary tarballs use a prefix of "/" which gets translated to "/bin/node"
+ # binary tarballs use a prefix of "/" which gets translated to "/bin/iojs"
# in the regular shebang modifying logic, which is incorrect since the
# precompiled bundle should be able to be extracted anywhere and "just work"